Crate tpl_generic_token

Crate tpl_generic_token 

Modules

associated_token_account
Partial TPL Associated Token Account declarations to avoid a dependency on the tpl-associated-token-account crate.
generic_token
Minimum viable TPL Token parsers to avoid a dependency on the tpl-token and tpl-token-2022 crates. Users may use the generic traits directly, but this requires them to select the correct implementation based on the account’s program id. generic_token::Account and generic_token::Mint abstract over this and require no knowledge of the different token programs on the part of the caller at all.
token
Partial TPL Token declarations to avoid a dependency on the tpl-token crate.
token_2022
Partial TPL Token declarations to avoid a dependency on the tpl-token-2022 crate.

Functions

is_known_tpl_token_id
Check if the provided program id as a known TPL Token program id
tpl_token_ids
Returns all known TPL Token program ids