Partial TPL Token declarations to avoid a dependency on the tpl-token crate.
Modules
Structs
Constants
- ID
- The const program ID.
- TPL_
TOKEN_ ACCOUNT_ MINT_ OFFSET - TPL_
TOKEN_ ACCOUNT_ OWNER_ OFFSET
Partial TPL Token declarations to avoid a dependency on the tpl-token crate.